@@ -17,6 +17,24 @@ from .xml_annotation import XMLAnnotation
 
 @ome_dataclass
 class StructuredAnnotations:
+    """An unordered collection of annotation attached to objects in the OME data
+    model.
+
+    Parameters
+    ----------
+    boolean_annotations : BooleanAnnotation, optional
+    comment_annotations : CommentAnnotation, optional
+    double_annotations : DoubleAnnotation, optional
+    file_annotations : FileAnnotation, optional
+    list_annotations : ListAnnotation, optional
+    long_annotations : LongAnnotation, optional
+    map_annotations : MapAnnotation, optional
+    tag_annotations : TagAnnotation, optional
+    term_annotations : TermAnnotation, optional
+    timestamp_annotations : TimestampAnnotation, optional
+    xml_annotations : XMLAnnotation, optional
+    """
+
     boolean_annotations: Optional[BooleanAnnotation] = None
     comment_annotations: Optional[CommentAnnotation] = None
     double_annotations: Optional[DoubleAnnotation] = None
